%define ALD_Ver		2.0
%define auto_local %{_sourcedir}/AUTO_LOCAL-1.sh
%define have_auto_local %(if test -x %{auto_local} ; then echo 1 ; else echo 0 ; fi)

%define USE_MESON 0

Name:         libpsl

License:      MIT
Summary:      Public Suffix List C library.
Version:      0.21.5
Release:      0

#https://github.com/rockdaboot/libpsl/releases/

#Requires:         gnutls = icu67

Source: %{name}-%{version}.tar.xz
%define DestDir		/net
# -----------------------------------------------------

%if %{_target_cpu} == %{_build_cpu}
%define _srcrpmdir	%{_topdir}/SRPMS/%{ALD_Ver}
%define _CROSS 0
%define MakeLocCross 0
%else
# rpm --target=armv7hl -ba xxxxx.spec
%define _srcrpmdir	%{_topdir}/SRPMS/tmp
%define _CROSS 1
%define MakeLocCross 1
%define _host %{_arch}-%{_os}%{_gnu}
%endif

#------------------ CROSS DIR --------------------

%define docdir		%{_defaultdocdir}/%{name}

%if %{have_auto_local}
%define __os_install_post %{nil}
%define CrossPath	%(%{auto_local} -GetCrossPath -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu})
%endif

# ------------------- description ------------------------------------
%description
libpsl is a C library to handle the Public Suffix List. A "public suffix" is a
domain name under which Internet users can directly register own names.
#-------------------------------
%package devel
Summary:      Libraries for the C compiler
%description devel
These libraries are needed to compile C code.
#-------------------------------
%package make-dafsa
Summary:      Compiles the Public Suffix List into DAFSA form
%description make-dafsa
Compiles the Public Suffix List into DAFSA form
#-------------------------------
%package doc
Summary:      doc html for %{name}
%description doc
doc html for %{name}
#-------------------------------
%package %{_target_cpu}
Summary:      %{name} Cross-%{_target_cpu}
Buildarch:    noarch
autoreqprov:  0
%description %{_target_cpu}
%{name} Cross-%{_target_cpu}

# ------------------- setup ------------------------------------------
%Prep
%setup -q -n %{name}-%{version}

sed -i s:"#!/usr/bin/env python":"#!/usr/bin/python3": src/psl-make-dafsa

# ------------------- Build ------------------------------------------
%Build
%if %{_CROSS}
PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif
export PATH

%if %{_arch} == "i386"
OPTFLAGS="-Os -march=i586 -mpreferred-stack-boundary=2 -falign-functions=1 -falign-jumps=1 -falign-loops=1 -fomit-frame-pointer"
%endif
%if %{_arch} == "x86_64"
OPTFLAGS="-Os"
%endif
%if %{_arch} == "arm"
OPTFLAGS="%{optflags} -Os -munaligned-access"
%endif

OPTFLAGS="$OPTFLAGS -fno-asynchronous-unwind-tables"

CFLAGS="$OPTFLAGS -std=gnu99"
CXXFLAGS="$OPTFLAGS"
LDFLAGS="-Wl,--gc-sections"
%if %{USE_MESON}

export CFLAGS CXXFLAGS LDFLAGS

%define srcdir "`pwd`"

meson   --buildtype=plain \
    --prefix=%{_prefix} \
    --libdir=%{_libdir} \
    --libexecdir=%{_libexecdir} \
    --bindir=%{_bindir} \
    --sbindir=%{_sbindir} \
    --includedir=%{_includedir} \
    --datadir=%{_datadir} \
    --mandir=%{_mandir} \
    --infodir=%{_infodir} \
    --localedir=%{_datadir}/locale \
    --sysconfdir=%{_sysconfdir} \
    --localstatedir=%{_localstatedir} \
    --sharedstatedir=%{_sharedstatedir} \
    --wrap-mode=nodownload \
    -Dpsl_distfile=%{_datadir}/publicsuffix/public_suffix_list.dafsa \
    -Dpsl_file=%{_datadir}/publicsuffix/effective_tld_names.dat \
    -Dpsl_testfile=%{_datadir}/publicsuffix/test_psl.txt \
    %{srcdir}  _Build \
    &>FConfigure_log.txt

ninja -C _Build &>FMake_log.txt

%else

%configure --disable-silent-rules \
	--disable-static \
	--disable-libtool-lock \
	--disable-nls \
	--disable-rpath \
	--enable-gtk-doc \
	--with-psl-distfile=%{_datadir}/publicsuffix/public_suffix_list.dafsa \
	--with-psl-file=%{_datadir}/publicsuffix/effective_tld_names.dat \
	--with-psl-testfile=%{_datadir}/publicsuffix/test_psl.txt \
	&>FConfigure_log.txt

make &>FMake_log.txt

%endif

# ------------------- Install ----------------------------------------
%Install
%if %{_CROSS}
export PATH="%{CrossPath}/bin:$PATH"
export GCC_NoHostPath=d
%endif

rm -rf $RPM_BUILD_ROOT
mkdir -p %{_srcrpmdir}
mkdir -p $RPM_BUILD_ROOT%{docdir}

%if %{USE_MESON}
DESTDIR=$RPM_BUILD_ROOT ninja -C _Build install &>Finstall_log.txt
%else
make DESTDIR=$RPM_BUILD_ROOT install &>Finstall_log.txt
rm $RPM_BUILD_ROOT%{_libdir}/*.la
%endif

cp AUTHORS COPYING $RPM_BUILD_ROOT%{docdir}/
cp src/psl-make-dafsa $RPM_BUILD_ROOT%{_bindir}/

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} -DelLocCrossDir=%{_bindir}
%endif  # have_auto_local

# ------------------- Clean ------------------------------------------
%Clean

%if %{have_auto_local}
  %{auto_local} -build_cpu=%{_build_cpu} -target_cpu=%{_target_cpu} \
	-MakeLocCross=%{MakeLocCross} \
	-ALD_Ver=%{ALD_Ver} -RpmMovePath=%{DestDir} -tar_arg=bzip2
%endif  # have_auto_local

# ------------------- Files ------------------------------------------
%files
%{_bindir}/psl
%{_libdir}/libpsl.so.*
%{docdir}
%{_mandir}/man1

%files devel
%{_includedir}
%{_libdir}/libpsl.so
%{_libdir}/pkgconfig

%files make-dafsa
%{_bindir}/psl-make-dafsa

%files doc
%{_datadir}/gtk-doc/html/libpsl

# ------------------- Cross Files ------------------------------------
%if %{MakeLocCross} && %{have_auto_local}

%files %{_target_cpu}
%{CrossPath}%{_libdir}
%{CrossPath}%{_includedir}
%{CrossPath}%{docdir}

%endif # MakeLocCross
